Index: src/x64/full-codegen-x64.cc |
diff --git a/src/x64/full-codegen-x64.cc b/src/x64/full-codegen-x64.cc |
index 473f548500b170793864daa0ab227446d532b900..2affd2cb5e7638c637c2af2827410258c9a854d8 100644 |
--- a/src/x64/full-codegen-x64.cc |
+++ b/src/x64/full-codegen-x64.cc |
@@ -3628,13 +3628,11 @@ void FullCodeGenerator::EmitStringCompare(CallRuntime* expr) { |
void FullCodeGenerator::EmitMathLog(CallRuntime* expr) { |
- // Load the argument on the stack and call the stub. |
- TranscendentalCacheStub stub(TranscendentalCache::LOG, |
- TranscendentalCacheStub::TAGGED); |
+ // Load the argument on the stack and call the runtime function. |
ZoneList<Expression*>* args = expr->arguments(); |
ASSERT(args->length() == 1); |
VisitForStackValue(args->at(0)); |
- __ CallStub(&stub); |
+ __ CallRuntime(Runtime::kMath_log, 1); |
context()->Plug(rax); |
} |